@@ -58,6 +58,66 @@
   (when (and value (stringp value))
     (substring-no-properties value)))
 
+(defun vulpea-db--strip-emphasis (str)
+  "Strip Org emphasis markers from STR.
+
+Removes emphasis markers for bold (*), italic (/), underline (_),
+strikethrough (+), code (=), and verbatim (~).
+
+Respects Org's emphasis rules: markers must be at word boundaries
+and content must not start or end with whitespace.
+
+Returns STR with emphasis markers removed, or nil if STR is nil."
+  (when str
+    (let ((result str))
+      ;; Process each emphasis marker type
+      ;; Pattern based on org-emph-re and org-verbatim-re structure:
+      ;; - Pre: beginning of string OR space/punctuation
+      ;; - Marker + non-whitespace content + same marker
+      ;; - Post: end of string OR space/punctuation
+      (dolist (marker '("\\*" "/" "_" "\\+" "=" "~"))
+        (let ((re (concat
+                   ;; Pre-marker context (group 1)
+                   "\\(^\\|[-[:space:]('\"{]\\)"
+                   ;; The emphasis: marker + content + marker (group 2 = full, group 3 = content)
+                   marker
+                   "\\([^[:space:]]\\|[^[:space:]][^" marker "]*[^[:space:]]\\)"
+                   marker
+                   ;; Post-marker context (group 4)
+                   "\\([-[:space:].,:!?;'\")}\\[]\\|$\\)")))
+          (while (string-match re result)
+            (setq result (replace-match "\\1\\2\\3" nil nil result)))))
+      result)))
+
+(defun vulpea-db--extract-links-from-string (str &optional base-pos)
+  "Extract org links from raw STR.
+
+Returns list of plists with :dest, :type, :pos, and :description.
+This is used for extracting links from keyword values like
+#+TITLE or heading raw-values where org-element does not parse
+links as elements.
+
+BASE-POS is the buffer position of the start of STR.  Each
+link's :pos is computed as BASE-POS + match offset within STR.
+When BASE-POS is nil, the match offset within STR is used."
+  (let ((result nil)
+        (pos 0))
+    (while (string-match org-link-bracket-re str pos)
+      (let ((match-start (match-beginning 0))
+            (description (match-string 2 str)))
+        (setq pos (match-end 0))
+        (let* ((raw-link (match-string 1 str))
+               (type-and-path (if (string-match "\\`\\([^:]+\\):\\(.*\\)" raw-link)
+                                  (cons (match-string 1 raw-link)
+                                        (match-string 2 raw-link))
+                                (cons "fuzzy" raw-link))))
+          (push (list :dest (cdr type-and-path)
+                      :type (car type-and-path)
+                      :pos (+ (or base-pos 0) match-start)
+                      :description description)
+                result))))
+    (nreverse result)))
+
 (defsubst vulpea-db--strings-no-properties (values)
   "Return VALUES list with text properties stripped from each element."
   (when values
@@ -238,7 +298,7 @@ after loading PATH so file-local keywords and hooks are respected."
   (let ((vulpea-db--parse-buffer-run-hooks rerun-org-mode))
     (vulpea-db--with-parse-buffer
       (let* ((t0 (current-time))
-             (_ (progn
+             (_ (let ((inhibit-read-only t))
                   (erase-buffer)
                   (insert-file-contents path)))
              (t1 (current-time))
@@ -298,9 +358,16 @@ Returns `vulpea-parse-ctx' structure with:
 - Heading-level node data (if enabled)
 - File metadata (hash, mtime, size)
 
-Respects `vulpea-db-parse-method' setting for parsing approach."
-  (let ((vulpea-db--active-parse-method vulpea-db-parse-method))
-    (pcase vulpea-db-parse-method
+Respects `vulpea-db-parse-method' setting for parsing approach.
+
+For non-.org files (e.g., .org.age, .org.gpg), always uses the
+`find-file' method regardless of `vulpea-db-parse-method' to
+ensure decryption hooks run properly."
+  (let* ((vulpea-db--active-parse-method vulpea-db-parse-method)
+         (method (if (string-suffix-p ".org" path)
+                     vulpea-db-parse-method
+                   'find-file)))
+    (pcase method
       ('single-temp-buffer
        (vulpea-db--parse-with-temp-buffer path nil))
 
@@ -345,7 +412,9 @@ Returns the #+TITLE keyword value if present, otherwise the filename base."
                              (org-element-property :key kw))
                             (vulpea-db--string-no-properties
                              (org-element-property :value kw)))))))
-    (or (cdr (assoc "TITLE" keywords))
+    (or (when-let* ((title (cdr (assoc "TITLE" keywords))))
+          (vulpea-db--strip-emphasis
+           (org-link-display-format title)))
         (file-name-base path))))
 
 (defun vulpea-db--extract-file-node (ast path buffer file-title)
@@ -370,15 +439,34 @@ Returns nil if:
          (properties (vulpea-db--extract-properties ast nil))
          (id (cdr (assoc "ID" properties)))
          (ignored (cdr (assoc "VULPEA_IGNORE" properties)))
-         (filetags-str (cdr (assoc "FILETAGS" keywords)))
-         (filetags (when filetags-str
-                     (split-string filetags-str ":" t)))
+         (filetags (cl-mapcan (lambda (kw)
+                                (when (string= "FILETAGS" (car kw))
+                                  (split-string (cdr kw) ":" t)))
+                              keywords))
          (archived (vulpea-db--archived-p nil properties filetags)))
 
     ;; Only index if ID exists, not explicitly ignored, and not archived
     (when (and id (not ignored) (not archived))
-      (let* ((meta (vulpea-db--extract-meta ast))
-             (links (vulpea-db--extract-links ast t))  ; Don't recurse into headlines
+      (let* ((title-kw (org-element-map ast 'keyword
+                         (lambda (kw)
+                           (when (string= "TITLE"
+                                          (org-element-property :key kw))
+                             kw))
+                         nil t))
+             (raw-title (when title-kw
+                          (vulpea-db--string-no-properties
+                           (org-element-property :value title-kw))))
+             (title-value-pos
+              (when title-kw
+                (+ (org-element-property :begin title-kw)
+                   ;; skip "#+TITLE: " prefix to get to value
+                   (length "#+TITLE: "))))
+             (title-links (when raw-title
+                            (vulpea-db--extract-links-from-string
+                             raw-title title-value-pos)))
+             (meta (vulpea-db--extract-meta ast))
+             (links (append title-links
+                            (vulpea-db--extract-links ast t)))  ; Don't recurse into headlines
              (aliases (vulpea-db--extract-aliases properties))
              (attach-dir (with-current-buffer buffer
                            (require 'org-attach)
@@ -415,15 +503,15 @@ Skips headings that:
 
 Respects `vulpea-db-index-heading-level' setting."
   (when (vulpea-db--should-index-headings-p path)
-    ;; Extract filetags once for archive checking
-    (let* ((filetags-str (org-element-map ast 'keyword
-                           (lambda (kw)
-                             (when (string= "FILETAGS"
-                                            (org-element-property :key kw))
-                               (org-element-property :value kw)))
-                           nil t))
-           (filetags (when filetags-str
-                       (split-string filetags-str ":" t))))
+    ;; Extract filetags once for archive checking and tag inheritance
+    (let* ((filetags (apply #'append
+                            (org-element-map ast 'keyword
+                              (lambda (kw)
+                                (when (string= "FILETAGS"
+                                               (org-element-property :key kw))
+                                  (split-string
+                                   (org-element-property :value kw)
+                                   ":" t)))))))
       (org-element-map ast 'headline
         (lambda (headline)
           (when-let* ((id (org-element-property :ID headline)))
@@ -432,10 +520,38 @@ Respects `vulpea-db-index-heading-level' setting."
                    (archived (vulpea-db--archived-p headline properties filetags)))
               ;; Only index if not explicitly ignored and not archived
               (unless (or ignored archived)
-                (let* ((title (vulpea-db--string-no-properties
-                               (org-element-property :raw-value headline)))
-                       (tags (vulpea-db--strings-no-properties
-                              (org-element-property :tags headline)))
+                (let* ((title (vulpea-db--strip-emphasis
+                               (org-link-display-format
+                                (vulpea-db--string-no-properties
+                                 (org-element-property :raw-value headline)))))
+                       (inherited-tags
+                        (when org-use-tag-inheritance
+                          (let (parent-tags
+                                (current headline))
+                            ;; Walk bottom-up, but build top-down order
+                            ;; by prepending each level's tags to the
+                            ;; accumulator (outermost ends up first).
+                            (while (setq current (org-element-property :parent current))
+                              (when (eq (org-element-type current) 'headline)
+                                (let (level-tags)
+                                  (dolist (tag (vulpea-db--strings-no-properties
+                                               (org-element-property :tags current)))
+                                    (when (org-tag-inherit-p tag)
+                                      (push tag level-tags)))
+                                  (setq parent-tags
+                                        (append (nreverse level-tags)
+                                                parent-tags)))))
+                            ;; Prepend inheritable filetags
+                            (let (filtered-filetags)
+                              (dolist (tag filetags)
+                                (when (org-tag-inherit-p tag)
+                                  (push tag filtered-filetags)))
+                              (append (nreverse filtered-filetags)
+                                      parent-tags)))))
+                       (tags (seq-uniq
+                              (append inherited-tags
+                                      (vulpea-db--strings-no-properties
+                                       (org-element-property :tags headline)))))
                        (level (org-element-property :level headline))
                        (pos (org-element-property :begin headline))
                        (todo (vulpea-db--string-no-properties
@@ -444,14 +560,31 @@ Respects `vulpea-db-index-heading-level' setting."
                        (scheduled (org-element-property :scheduled headline))
                        (deadline (org-element-property :deadline headline))
                        (closed (org-element-property :closed headline))
-                       (meta (vulpea-db--extract-meta headline))
-                       (links (vulpea-db--extract-links headline t))
+                       ;; Extract meta from the section element (first child of headline)
+                       ;; because org-element-map with NO-RECURSION 'headline won't
+                       ;; descend into a headline element itself
+                       (section (seq-find (lambda (el)
+                                            (eq (org-element-type el) 'section))
+                                          (org-element-contents headline)))
+                       (meta (when section
+                               (vulpea-db--extract-meta section)))
+                       (raw-title (vulpea-db--string-no-properties
+                                   (org-element-property :raw-value headline)))
+                       (title-start (+ pos level 1 ; stars + space
+                                     (if todo (+ (length todo) 1) 0)
+                                     (if priority 4 0))) ; "[#X] "
+                       (title-links (vulpea-db--extract-links-from-string
+                                     raw-title title-start))
+                       (links (append title-links
+                                      (vulpea-db--extract-links headline t)))
                        (outline-path (let (path
                                            (current headline))
                                        (while (setq current (org-element-property :parent current))
                                          (when (eq (org-element-type current) 'headline)
-                                           (push (vulpea-db--string-no-properties
-                                                  (org-element-property :raw-value current))
+                                           (push (vulpea-db--strip-emphasis
+                                                  (org-link-display-format
+                                                   (vulpea-db--string-no-properties
+                                                    (org-element-property :raw-value current))))
                                                  path)))
                                        path))
                        (attach-dir (with-current-buffer buffer
@@ -464,7 +597,7 @@ Respects `vulpea-db-index-heading-level' setting."
                         :level level
                         :pos pos
                         :title title
-                        :aliases nil  ; Only file-level has aliases
+                        :aliases (vulpea-db--extract-aliases properties)
                         :tags tags
                         :links links
                         :properties properties
@@ -503,7 +636,8 @@ Respects `vulpea-db-index-heading-level' setting:
   "Extract aliases from PROPERTIES alist.
 
 Looks for property defined by `vulpea-buffer-alias-property'.
-Handles both quoted aliases (with spaces) and unquoted aliases properly."
+Handles both quoted aliases (with spaces) and unquoted aliases properly.
+Strips org links and emphasis markers from each alias."
   (when-let* ((aliases-str (cdr (assoc vulpea-buffer-alias-property properties))))
     (setq aliases-str (string-trim aliases-str))
     (let ((result nil)
@@ -521,14 +655,20 @@ Handles both quoted aliases (with spaces) and unquoted aliases properly."
               (let ((end (string-match "\"" aliases-str (1+ pos))))
                 (if end
                     (progn
-                      (push (substring aliases-str (1+ pos) end) result)
+                      (push (vulpea-db--strip-emphasis
+                             (org-link-display-format
+                              (substring aliases-str (1+ pos) end)))
+                            result)
                       (setq pos (1+ end)))
                   (error "Unmatched quote in %s" vulpea-buffer-alias-property))))
              ;; Unquoted alias - find next space or end of string
              (t
               (let ((end (or (string-match " " aliases-str pos)
                              (length aliases-str))))
-                (push (substring aliases-str pos end) result)
+                (push (vulpea-db--strip-emphasis
+                       (org-link-display-format
+                        (substring aliases-str pos end)))
+                      result)
                 (setq pos end)))))))
       (nreverse result))))
 
@@ -544,8 +684,8 @@ Returns alist of (key . value) pairs."
       (lambda (drawer)
         (org-element-map drawer 'node-property
           (lambda (prop)
-            (cons (vulpea-db--string-no-properties
-                   (org-element-property :key prop))
+            (cons (upcase (vulpea-db--string-no-properties
+                          (org-element-property :key prop)))
                   (vulpea-db--string-no-properties
                    (org-element-property :value prop))))))
       nil t)))  ; First match only
@@ -557,31 +697,76 @@ Returns list of plists with :dest, :type, and :pos.
 Captures all link types: id:, roam:, file:, http:, https:,
 attachment:, elisp:, and any other `org-mode' link type.
 
-If NO-RECURSION is non-nil, stops recursion at headline boundaries.
-This is useful for file-level extraction to avoid collecting links
-from child headlines.  For headline elements, this extracts links
-only from the section (direct content) without child headlines."
-  (if (and no-recursion (eq (org-element-type ast-or-node) 'headline))
-      ;; For headlines with no-recursion, only search the section
-      ;; (direct content before any child headlines)
-      (let ((section (org-element-map ast-or-node 'section #'identity nil t)))
-        (when section
-          (org-element-map section 'link
-            (lambda (link)
-              (let ((type (org-element-property :type link))
-                    (path (org-element-property :path link))
-                    (pos (org-element-property :begin link)))
-                (when (and type path)
-                  (list :dest path :type type :pos pos)))))))
-    ;; Normal case: search everything, optionally stopping at headlines
+If NO-RECURSION is non-nil, stops recursion at note boundaries
+\(headlines with an ID property).  Links inside non-note subtrees
+are collected as part of the current node.  This prevents links
+from child notes leaking to the parent while still capturing
+links from plain (non-note) subtrees."
+  (if no-recursion
+      (vulpea-db--extract-links-stopping-at-notes ast-or-node)
+    ;; Normal case: search everything without restrictions
     (org-element-map ast-or-node 'link
       (lambda (link)
         (let ((type (org-element-property :type link))
               (path (org-element-property :path link))
-              (pos (org-element-property :begin link)))
+              (pos (org-element-property :begin link))
+              (desc (when-let ((contents (org-element-contents link)))
+                      (substring-no-properties
+                       (org-element-interpret-data contents)))))
           (when (and type path)
-            (list :dest path :type type :pos pos))))
-      nil nil (when no-recursion 'headline))))
+            (list :dest path :type type :pos pos :description desc)))))))
+
+(defun vulpea-db--extract-links-stopping-at-notes (node)
+  "Extract links from NODE, stopping at note boundaries.
+
+Collects links from NODE but does not descend into child
+headlines that have an ID property (note boundaries).  Links
+inside non-note child headlines are included."
+  (let ((result nil))
+    (vulpea-db--walk-links-skipping-notes node (lambda (link) (push link result)))
+    (nreverse result)))
+
+(defun vulpea-db--walk-links-skipping-notes (node callback)
+  "Walk NODE collecting links via CALLBACK, skipping note headlines.
+
+CALLBACK is called with a plist (:dest :type :pos :description) for each link.
+Descends into child headlines only if they lack an ID property."
+  (dolist (child (org-element-contents node))
+    (let ((child-type (org-element-type child)))
+      (cond
+       ;; Link element: collect it
+       ((eq child-type 'link)
+        (let ((type (org-element-property :type child))
+              (path (org-element-property :path child))
+              (pos (org-element-property :begin child))
+              (desc (when-let ((contents (org-element-contents child)))
+                      (substring-no-properties
+                       (org-element-interpret-data contents)))))
+          (when (and type path)
+            (funcall callback (list :dest path :type type :pos pos
+                                    :description desc)))))
+       ;; Headline with ID: skip (note boundary)
+       ((and (eq child-type 'headline)
+             (org-element-property :ID child))
+        nil)
+       ;; Headline without ID: extract title links, then recurse
+       ((eq child-type 'headline)
+        (let* ((raw-value (org-element-property :raw-value child))
+               (h-level (org-element-property :level child))
+               (h-todo (org-element-property :todo-keyword child))
+               (h-priority (org-element-property :priority child))
+               (h-begin (org-element-property :begin child))
+               (title-start (+ h-begin h-level 1
+                               (if h-todo (+ (length h-todo) 1) 0)
+                               (if h-priority 4 0))))
+          (when raw-value
+            (dolist (link (vulpea-db--extract-links-from-string
+                          raw-value title-start))
+              (funcall callback link))))
+        (vulpea-db--walk-links-skipping-notes child callback))
+       ;; Anything else (section, paragraph, etc.): recurse
+       ((org-element-contents child)
+        (vulpea-db--walk-links-skipping-notes child callback))))))
 
 (defun vulpea-db--extract-meta (element)
   "Extract metadata from ELEMENT (AST or headline element).
