@@ -590,5 +590,169 @@ Notes that don't exist are omitted from results."
                          (vconcat ids))))
       (mapcar #'vulpea-db--row-to-note rows))))
 
+;;; Diagnostic Queries
+
+(defun vulpea-db-query-dead-links ()
+  "Find broken ID links pointing to non-existent notes.
+
+Returns list of cons cells (SOURCE-NOTE . BROKEN-TARGET-ID) where
+SOURCE-NOTE is a `vulpea-note' struct and BROKEN-TARGET-ID is the
+ID string that has no matching note in the database.
+
+Only checks links of type \"id\". Other link types (http, file,
+etc.) are ignored."
+  (let* ((rows (emacsql (vulpea-db)
+                        [:select [source dest]
+                         :from links
+                         :where (and (= type "id")
+                                     (not (in dest [:select [id]
+                                                    :from notes])))]))
+         (source-ids (delete-dups (mapcar #'car rows)))
+         (source-notes (when source-ids
+                         (vulpea-db-query-by-ids source-ids)))
+         (notes-by-id (make-hash-table :test #'equal)))
+    (dolist (note source-notes)
+      (puthash (vulpea-note-id note) note notes-by-id))
+    (mapcar (lambda (row)
+              (cons (gethash (car row) notes-by-id)
+                    (cadr row)))
+            rows)))
+
+(defun vulpea-db-query-orphan-notes ()
+  "Find notes with no incoming ID links.
+
+Returns list of `vulpea-note' structs for notes whose ID does not
+appear as a destination in any link of type \"id\".
+
+Notes that have outgoing links but no incoming links are included.
+See `vulpea-db-query-isolated-notes' for notes with no connections
+in either direction."
+  (let ((rows (emacsql (vulpea-db)
+                       [:select * :from notes
+                        :where (not (in id [:select :distinct [dest]
+                                            :from links
+                                            :where (= type "id")]))])))
+    (mapcar #'vulpea-db--row-to-note rows)))
+
+(defun vulpea-db-query-isolated-notes ()
+  "Find notes with no incoming or outgoing ID links.
+
+Returns list of `vulpea-note' structs for notes that have zero
+connections in either direction — neither linked to nor linking to
+any other note via \"id\" links.
+
+This is stricter than `vulpea-db-query-orphan-notes' which only
+checks for missing incoming links."
+  (let ((rows (emacsql (vulpea-db)
+                       [:select * :from notes
+                        :where (and (not (in id [:select :distinct [dest]
+                                                 :from links
+                                                 :where (= type "id")]))
+                                    (not (in id [:select :distinct [source]
+                                                 :from links
+                                                 :where (= type "id")])))])))
+    (mapcar #'vulpea-db--row-to-note rows)))
+
+(defun vulpea-db-query-title-collisions (&optional level)
+  "Find notes that share the same title.
+
+LEVEL optionally restricts to notes at a specific heading level.
+Use 0 for file-level notes only, or a positive integer for
+heading-level notes at that depth.  When nil, all levels are
+considered.
+
+Returns list of cons cells (TITLE . NOTES) where TITLE is a
+string and NOTES is a list of `vulpea-note' structs that all have
+that title.
+
+Only groups with two or more notes are returned."
+  (let* ((titles (mapcar #'car
+                         (if level
+                             (emacsql (vulpea-db)
+                                      [:select [title]
+                                       :from notes
+                                       :where (= level $s1)
+                                       :group :by title
+                                       :having (> (funcall count *) 1)]
+                                      level)
+                           (emacsql (vulpea-db)
+                                    [:select [title]
+                                     :from notes
+                                     :group :by title
+                                     :having (> (funcall count *) 1)]))))
+         (rows (when titles
+                 (if level
+                     (emacsql (vulpea-db)
+                              [:select * :from notes
+                               :where (and (in title $v1)
+                                           (= level $s2))
+                               :order :by title]
+                              (vconcat titles)
+                              level)
+                   (emacsql (vulpea-db)
+                            [:select * :from notes
+                             :where (in title $v1)
+                             :order :by title]
+                            (vconcat titles)))))
+         (notes (mapcar #'vulpea-db--row-to-note rows))
+         (groups (make-hash-table :test #'equal)))
+    (dolist (note notes)
+      (push note (gethash (vulpea-note-title note) groups)))
+    (let (result)
+      (maphash (lambda (title group)
+                 (push (cons title (nreverse group)) result))
+               groups)
+      result)))
+
+;;; Link Queries
+
+(defun vulpea-db-query-links ()
+  "Return all links in the database.
+
+Returns list of plists with :source, :dest, :type, :pos, and :description keys."
+  (mapcar #'vulpea-db--row-to-link
+          (emacsql (vulpea-db)
+                   [:select * :from links])))
+
+(defun vulpea-db-query-links-by-type (type)
+  "Return all links of TYPE.
+
+TYPE is a link type string (e.g., \"id\", \"https\", \"file\").
+
+Returns list of plists with :source, :dest, :type, :pos, and :description keys."
+  (mapcar #'vulpea-db--row-to-link
+          (emacsql (vulpea-db)
+                   [:select * :from links
+                    :where (= type $s1)]
+                   type)))
+
+(defun vulpea-db-query-links-from (id)
+  "Return all links originating from note with ID.
+
+Returns list of plists with :source, :dest, :type, :pos, and :description keys."
+  (mapcar #'vulpea-db--row-to-link
+          (emacsql (vulpea-db)
+                   [:select * :from links
+                    :where (= source $s1)]
+                   id)))
+
+(defun vulpea-db-query-links-to (id)
+  "Return all links pointing to note with ID.
+
+Returns list of plists with :source, :dest, :type, :pos, and :description keys."
+  (mapcar #'vulpea-db--row-to-link
+          (emacsql (vulpea-db)
+                   [:select * :from links
+                    :where (= dest $s1)]
+                   id)))
+
+(defun vulpea-db--row-to-link (row)
+  "Convert a links table ROW to a plist."
+  (list :source (nth 0 row)
+        :dest (nth 1 row)
+        :type (nth 2 row)
+        :pos (nth 3 row)
+        :description (nth 4 row)))
+
 (provide 'vulpea-db-query)
 ;;; vulpea-db-query.el ends here
