@@ -87,9 +87,27 @@ to be queried. Excluding them keeps the database cleaner and faster."
   :type 'boolean
   :group 'vulpea-db)
 
+(defcustom vulpea-db-extra-extensions nil
+  "List of extra file extensions to track besides .org files.
+
+Each entry is a suffix string with leading dot, e.g. \".org.age\".
+
+Files with these extensions are always parsed using the `find-file'
+method (regardless of `vulpea-db-parse-method') so that decryption
+hooks (age.el, epa-file) can run.
+
+WARNING: metadata (titles, tags, links) from encrypted files will
+be stored in the plaintext database.  Only opt in if you accept
+this trade-off.
+
+Example:
+  (setq vulpea-db-extra-extensions \\='(\".org.age\" \".org.gpg\"))"
+  :type '(repeat string)
+  :group 'vulpea-db)
+
 ;;; Constants
 
-(defconst vulpea-db-version 2
+(defconst vulpea-db-version 3
   "Current database schema version.")
 
 (defconst vulpea-db--schema
@@ -104,7 +122,7 @@ to be queried. Excluding them keeps the database cleaner and faster."
       (tags)                        ; JSON array ["tag1", "tag2"]
       (aliases)                     ; JSON array
       (meta)                        ; JSON object {key: [value1, value2]}
-      (links)                       ; JSON array [{dest, type, pos}]
+      (links)                       ; JSON array [{dest, type, pos, description}]
       (todo)
       (priority)
       (scheduled)
@@ -128,7 +146,8 @@ to be queried. Excluding them keeps the database cleaner and faster."
      [(source :not-null)
       (dest :not-null)
       (type :not-null)
-      (pos :not-null)]
+      (pos :not-null)
+      description]
      (:primary-key [source dest type pos])
      (:foreign-key [source] :references notes [id] :on-delete :cascade))
 
@@ -183,6 +202,10 @@ Uses hybrid approach:
 (defvar vulpea-db--connection nil
   "Database connection.")
 
+(defvar vulpea-db--schema-rebuilt nil
+  "Non-nil if schema was rebuilt during last init.
+Checked by `vulpea-db-sync--start' to trigger automatic re-index.")
+
 ;;; Core API
 
 (defun vulpea-db ()
@@ -217,12 +240,31 @@ Use with caution!"
 
 ;;; Initialization
 
+(defun vulpea-db--needs-rebuild-p (db)
+  "Return non-nil if DB schema version doesn't match `vulpea-db-version'."
+  (condition-case nil
+      (let ((stored (caar (emacsql db
+                                   [:select [version] :from schema-registry
+                                    :where (= name "core")]))))
+        (and stored (not (= stored vulpea-db-version))))
+    ;; schema-registry doesn't exist → brand new DB, no rebuild needed
+    (error nil)))
+
 (defun vulpea-db--init ()
   "Initialize database connection and schema."
   (let ((db (emacsql-sqlite-builtin vulpea-db-location)))
     ;; Enable foreign keys
     (emacsql db [:pragma (= foreign-keys on)])
 
+    ;; Check if schema version mismatches
+    (when (vulpea-db--needs-rebuild-p db)
+      (emacsql-close db)
+      (delete-file vulpea-db-location)
+      (setq db (emacsql-sqlite-builtin vulpea-db-location))
+      (emacsql db [:pragma (= foreign-keys on)])
+      (setq vulpea-db--schema-rebuilt t)
+      (message "Vulpea: Schema version changed, rebuilding database..."))
+
     ;; Create tables
     (vulpea-db--create-tables db)
 
@@ -272,6 +314,10 @@ Use with caution!"
                         (format "SELECT name FROM sqlite_master WHERE type = 'index' AND name = '%s'"
                                 index-name))))))
 
+(defun vulpea-db--all-extensions ()
+  "Return all tracked file extensions (`.org' + extras)."
+  (cons ".org" vulpea-db-extra-extensions))
+
 ;;; CRUD Operations
 
 (defun vulpea-db--plist-to-alist (plist)
@@ -320,7 +366,7 @@ Arguments:
   ALIASES - list of aliases
   META - alist of (key . values) where values is list of plists with
     :type and :value
-  LINKS - list of plists with :dest, :type, and :pos
+  LINKS - list of plists with :dest, :type, :pos, and :description
   TODO - TODO state
   PRIORITY - priority level
   SCHEDULED - scheduled timestamp
@@ -359,7 +405,8 @@ Arguments:
                            (vector id
                                    (plist-get link :dest)
                                    (plist-get link :type)
-                                   (plist-get link :pos)))
+                                   (plist-get link :pos)
+                                   (plist-get link :description)))
                          links)))
 
       ;; 4. Insert into normalized meta table
